package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Mar 31, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package gen implements code generation for protoc-gen-procframe-go.
Generate processes a single proto file and emits handler interface
and CLI runner files for each service that has CLI-exposed methods.
type Params struct {
ConfigProto string
}
Params holds plugin parameters parsed from protoc --<plugin>_opt flags.
Set implements the flag.Value-style callback expected by protogen.Options.ParamFunc.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.